Access and search research papers on the HuggingFace Hub.
The Hub indexes arXiv papers and links them to associated models, datasets, and demos. Papers can be browsed, searched, and linked to repositories.
See: https://huggingface.co/papers
Example
# List daily papers
{:ok, papers} = HuggingfaceClient.list_papers(access_token: "hf_...")
# Search papers
{:ok, results} = HuggingfaceClient.search_papers("vision language model",
access_token: "hf_..."
)
# Get a specific paper
{:ok, paper} = HuggingfaceClient.paper_info("2310.06825",
access_token: "hf_..."
)
Summary
Functions
Gets detailed information about a specific paper by its arXiv ID.
Lists the daily papers featured on the Hub.
Gets papers associated with a model, dataset, or space repository.
Searches for papers by keyword or phrase.
Functions
@spec info( String.t(), keyword() ) :: {:ok, map()} | {:error, Exception.t()}
Gets detailed information about a specific paper by its arXiv ID.
Example
{:ok, paper} = HuggingfaceClient.paper_info("2310.06825")
IO.puts("Title: #{paper["title"]}")
IO.puts("Authors: #{Enum.join(paper["authors"], ", ")}")
@spec list(keyword()) :: {:ok, [map()]} | {:error, Exception.t()}
Lists the daily papers featured on the Hub.
Options
:date— ISO 8601 date string to get papers for a specific day (e.g."2024-01-15"):limit— maximum number of papers to return:access_token
Example
{:ok, papers} = HuggingfaceClient.list_papers()
Enum.each(papers, fn p -> IO.puts(p["title"]) end)
@spec repo_papers( String.t(), keyword() ) :: {:ok, [map()]} | {:error, Exception.t()}
Gets papers associated with a model, dataset, or space repository.
Example
{:ok, papers} = HuggingfaceClient.repo_papers("openai/clip-vit-base-patch32")
@spec search( String.t(), keyword() ) :: {:ok, [map()]} | {:error, Exception.t()}
Searches for papers by keyword or phrase.
Example
{:ok, papers} = HuggingfaceClient.search_papers("diffusion models",
limit: 20
)